/*
** File: lock.h  
** Project: ADMXRC3 module driver
** Purpose: Defines function prototypes for I/O IOCTL handlers relating to locking
**          down user-space buffers.
**
** (C) Copyright Alpha Data 2009, 2015
*/

#if !defined(ADATA_ADMXRC3_LOCK_H)
#define ADATA_ADMXRC3_LOCK_H

#include <df.h>
#include "device.h"

extern BufferDescription*
referenceBufferHandle(
  Admxrc3DeviceContext* pDevCtx,
  Admxrc3ClientContext* pClCtx,
  uint32_t handle);

extern boolean_t
dereferenceBufferDescription(
  Admxrc3DeviceContext* pDevCtx,
  Admxrc3ClientContext* pClCtx,
  BufferDescription* pDescription);

extern void
cleanupLockedBuffers(
	Admxrc3DeviceContext* pDevCtx,
  Admxrc3ClientContext* pClCtx);

extern DfIoStatus
ioctlLock(
	Admxrc3DeviceContext* pDevCtx,
  Admxrc3ClientContext* pClCtx,
  void* pBuffer,
  unsigned int inSize,
  unsigned int outSize);

extern DfIoStatus
ioctlLockThunk(
	Admxrc3DeviceContext* pDevCtx,
  Admxrc3ClientContext* pClCtx,
  void* pBuffer,
  unsigned int inSize,
  unsigned int outSize);

extern DfIoStatus
ioctlUnlock(
	Admxrc3DeviceContext* pDevCtx,
  Admxrc3ClientContext* pClCtx,
  void* pBuffer,
  unsigned int inSize);

# if defined(ADMXRC3_LOCKED_BUFFERS_GLOBAL) && ADMXRC3_LOCKED_BUFFERS_GLOBAL
extern void
initLockedBuffers(
	DfDriverObject* pDrvObj);
# endif

#endif
